import 'dotenv/config';
import { drizzle } from 'drizzle-orm/bun-sqlite';
import { publisherTable, sourceTable } from './schema';
import publishers from './publishers';
import sources from './sources';

const db = drizzle({ connection: { source: process.env.DB_FILE_NAME! } });

async function deleteData() {
  await db.delete(publisherTable)
  console.log('- Publishers Deleted')

  await db.delete(sourceTable)
  console.log('- Sources Deleted')
}

async function seedData() {
  await db.insert(publisherTable).values(publishers)
  console.log('- Publishers Created')

  await db.insert(sourceTable).values(sources)
  console.log('- Sources Created')
}

(async () => {
  console.log('Deleting Existing Data...')
  await deleteData();
  console.log('Data Deleted!\n=====\nSeeding Data...')
  await seedData();
  console.log('Data Seeded!')
})().catch(err => {
  console.error(err);
});
